"""
Module to handle Scintec sodar .mnd files.

>>> from sodar.scintec import maindata
"""

__author__ = 'Chris Calloway'
__email__ = 'cbc@chriscalloway.org'
__copyright__ = 'Copyright 2009 UNC-CH Department of Marine Science'
__license__ = 'GPL2'

import os

class MainData(object):
    """
    Class to parse Scintec sodar .mnd files.
    
    Parse the format header:
    
    >>> main_data = MainData(good_mnd)
    >>> main_data._format_header[0]
    'FORMAT-1'
    """
    
    def __init__(self, mnd):
        """
        Parse main daily Scintec sodar .mnd file.
        
        MainData(mnd) -> <MainData object>
        
        Where mnd is a str object containing the complete contents read from a
        Scintec .mnd daily sodar file including all line endings.
        
        Parse a known good .mnd file:
        
        >>> main_data = MainData(good_mnd)
        """
        
        super(MainData, self).__init__()
        self._blocks = [self._block.strip()
                      for self._block in mnd.split('\n\n')
                      if self._block.strip()]
        self._format_header = [self._line.strip()
                              for self._line in self._blocks[0].split('\n')
                              if self._line.strip()]
        self._file_header = [self._line.strip()
                            for self._line in self._blocks[1].split('\n')
                            if self._line.strip()]
        self._profile_blocks = self._blocks[2:]
                            
def _test():
    """
    Run module tests in script mode.
    
    >>> from sodar.scintec.maindata import _test
    """
    import doctest
    from sodar.tests import suite
    good_mnd = suite.setUpGoodMndData()
    doctest.testmod(extraglobs=dict(good_mnd=good_mnd))

if __name__ == "__main__":
    _test()
